import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3'

const title = 'World Population';
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.population;
  const circleRadius = 6;
  const yAxisLabel = 'Population';
  
  const margin = {top: 60, right: 40, bottom: 88, left: 105};
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
  
	const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
      .domain([0,max(data,yValue)])
      .range([innerHeight,0])
  		.nice();
  
  const g = svg.append('g')
  		.attr('transform', `translate(${margin.left},${margin.top})`);
   
    const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  		.attr('class', 'line-path')
  		.attr('d', areaGenerator(data));
  
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickPadding(15)
  	.tickSize(-innerHeight);
  
  const yAxisTickFormat = number =>
  	format('.1s')(number)
  	.replace('G','B');
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
	yAxisG.selectAll('.domain').remove();
  
   yAxisG.append('text')
  			.attr('class','axis-lable')
  			.attr('y', -60)
  			.attr('x', -innerHeight / 2)
  			.attr('fill','black')
  			.attr('transform','rotate(-90)')
  			.attr('text-anchor','middle')
  			.text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  			.attr('class','axis-lable')
  			.attr('y',75)
  			.attr('x',innerWidth / 2)
  			.attr('fill','black')
  			.text(xAxisLabel);
  

  
  // g.selectAll('circle').data(data)
  //   .enter().append('circle')
  // 		.attr('cy',d => yScale(yValue(d)) )
  //     .attr('cx', d => xScale(xValue(d)))
  //     .attr('r', circleRadius);
  
  g.append('text')
  		.attr('class','title')
  		.attr('y',-15)
  		.attr('x',200)
      // .attr('text-anchor','middle')
  		.text(title);  	
};

csv('data.csv')
  .then(data => { 
  console.log(data);
  data.forEach(d => {
  	d.population = +d.population;
    d.year = new Date(d.year);
  });
	render(data);
});